
# Slot: affects uptake of


holds between two molecular entities where the action or effect of one impacts the rate of uptake of the other into of a cell, gland, or organ

URI: [biolink:affects_uptake_of](https://w3id.org/biolink/vocab/affects_uptake_of)


## Domain and Range

[MolecularEntity](MolecularEntity.md) &#8594;  <sub>0..\*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [affects](affects.md)

## Children

 *  [decreases uptake of](decreases_uptake_of.md)
 *  [increases uptake of](increases_uptake_of.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | CTD:affects_uptake_of |
| **Broad Mappings:** | | CTD:affects_import |

